package pizza;

import static org.hamcrest.Matchers.is;
import static org.junit.Assert.assertThat;

import java.awt.event.ActionEvent;
import java.util.Arrays;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class FunctionalTest
{
	private static final Pizza PIZZA_A = new PizzaNormal("A", 1000);
	private static final Pizza PIZZA_B = new PizzaChildren("B", 500);
	private static final Pizza PIZZA_C = new PizzaXXL("C", 1500);

	private OrderWindow window;

	@Before
	public void setup() {
		window = new OrderWindow(Arrays.asList(PIZZA_A, PIZZA_B, PIZZA_C));
	}

	@After
	public void teardown() {
		window.dispose();
		window = null;
	}

	@Test
	public void newBtnClicked_resetsUiToInitialState() {
		window.actionPerformed(new ActionEvent(window.newBtn, 0, ""));
		assertThat(window.nameField.getText(), is(""));
		assertThat(window.outputArea.getText(), is(""));
		assertThat(window.quantityField.getText(), is("1"));
	}

	@Test
	public void addBtnClicked_outputShouldBeGenerated() {
		window.actionPerformed(new ActionEvent(window.newBtn, 0, ""));
		window.nameField.setText("Max Mustermann");
		window.pizzaCombo.setSelectedIndex(0);
		window.actionPerformed(new ActionEvent(window.addBtn, 0, ""));
		String result = "Order Record for Max Mustermann\n"
				+ "    1 A                      1000\n"
				+ "   Total                     1000\n"
				+ "   Free Normal Pizzas           0\n";
		assertThat(window.outputArea.getText(), is(result));
	}

	@Test
	public void pizzaPoints_19NormalPizzasEquals1FreePizza() {
		window.nameField.setText("a");
		window.pizzaCombo.setSelectedIndex(0);
		window.quantityField.setText("19");
		window.actionPerformed(new ActionEvent(window.addBtn, 0, ""));
		String result = "Order Record for a\n"
				+ "   19 A                     19000\n"
				+ "   Total                    19000\n"
				+ "   Free Normal Pizzas           1\n";
		assertThat(window.outputArea.getText(), is(result));
	}

	@Test
	public void pizzaPoints_20NormalPizzasEquals2FreePizzas() {
		window.nameField.setText("a");
		window.pizzaCombo.setSelectedIndex(0);
		window.quantityField.setText("20");
		window.actionPerformed(new ActionEvent(window.addBtn, 0, ""));
		String result = "Order Record for a\n"
				+ "   20 A                     20000\n"
				+ "   Total                    20000\n"
				+ "   Free Normal Pizzas           2\n";
		assertThat(window.outputArea.getText(), is(result));
	}
	
	@Test
	public void orderPizza_caculatePrize() {
		OrderedPizza op1 = new OrderedPizza(1, new PizzaNormal("SOME_NAME", 1000));
		assertThat(op1.calculatePrize(), is(1 * 1000));
		
		OrderedPizza op2 = new OrderedPizza(10, new PizzaXXL("SOME_NAME", 100));
		assertThat(op2.calculatePrize(), is((int)(10 * 100 * 1.5)));
		
		OrderedPizza op3 = new OrderedPizza(5, new PizzaChildren("SOME_NAME", 8));
		assertThat(op3.calculatePrize(), is((int)(5 * 8 * 0.5)));
	}
	
	@Test
	public void orderPizza_caculatePoints() {
		OrderedPizza op1 = new OrderedPizza(1, new PizzaNormal("SOME_NAME", 1000));
		assertThat(op1.calculatePoints(), is(1 * 10));
		
		OrderedPizza op2 = new OrderedPizza(10, new PizzaXXL("SOME_NAME", 100));
		assertThat(op2.calculatePoints(), is((int)(10 * 15)));
		
		OrderedPizza op3 = new OrderedPizza(5, new PizzaChildren("SOME_NAME", 8));
		assertThat(op3.calculatePoints(), is((int)(5 * 0)));
	}
	
	@Test
	public void customer_totalPrice() {
		Customer c = new Customer("CUSTOMER_NAME");
		c.addOrder(new OrderedPizza(1, new PizzaNormal("PIZZA_NAME", 1000)));
		c.addOrder(new OrderedPizza(10, new PizzaXXL("PIZZA_NAME", 100)));
		c.addOrder(new OrderedPizza(5, new PizzaChildren("PIZZA_NAME", 8)));
		assertThat(c.getTotalPrice(), is((int)(1 * 1000 + 10 * 100 * 1.5 + 5 * 8 * 0.5)));
	}
	
	@Test
	public void customer_pizzaPoints() {
		Customer c = new Customer("CUSTOMER_NAME");
		c.addOrder(new OrderedPizza(1, new PizzaNormal("PIZZA_NAME", 1000)));
		c.addOrder(new OrderedPizza(10, new PizzaXXL("PIZZA_NAME", 100)));
		c.addOrder(new OrderedPizza(5, new PizzaChildren("PIZZA_NAME", 8)));
		assertThat(c.getPizzaPoints(), is((int)(1 * 10 + 10 * 15 + 5 * 0)));
	}
}
